@@ -18,7 +18,7 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Enum 0.055002;
+package Term::CLI::Argument::Enum 0.057001;
 
 use 5.014;
 use warnings;
@@ -52,7 +52,13 @@ has value_list => (
 
 has cache_values => (
     is       => 'rw',
-    default  => sub {0},
+    default  =>  0,
+# Trigger for when caching gets disabled to immediately clear the
+# cache. This allows for quicker cleanup of objects, file handles, etc.
+    trigger => sub {
+        my ($self, $new) = @_;
+        $self->_clear_value_cache if ! $new;
+    }
 );
 
 has _value_cache => (
@@ -71,12 +77,10 @@ sub values {
     # Dynamic values...
 
     # Return cache if possible.
-    if ( $self->cache_values && $self->_has_value_cache ) {
+    if ( $self->_has_value_cache ) {
         return $self->_value_cache;
     }
 
-    $self->_clear_value_cache;
-
     my $list_ref = [ sort @{ $value_list->($self) } ];
 
     if ( $self->cache_values ) {
@@ -86,15 +90,6 @@ sub values {
     return $list_ref;
 }
 
-# Trigger for when caching gets disabled to immediately clear the
-# cache. This allows for quicker cleanup of objects, file handles, etc.
-after cache_values => sub {
-    my ($self, @args) = @_;
-
-    if (@args && !$args[0]) {
-        $self->_clear_value_cache;
-    }
-};
 
 sub validate {
     my ( $self, $value ) = @_;
@@ -136,7 +131,7 @@ Term::CLI::Argument::Enum - class for "enum" string arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.055002
+version 0.057001
 
 =head1 SYNOPSIS
 
